@@ -214,7 +214,7 @@ fortify.pems <- function (model, data, ...) {
 #pems.utils
 
 
-select.pems <- function (.data, ...){
+##select.pems <- function (.data, ...){
 
 ############################################
 #this is overkill because I am currently running two versions of the pems object
@@ -233,78 +233,78 @@ select.pems <- function (.data, ...){
 #select(pems, speed=velocity)
 
     #for new build only
-    .data <- rebuildPEMS(.data, "new")
+##    .data <- rebuildPEMS(.data, "new")
 
-    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("units", "pems.tags")]
-    attributes(.data)$units <- NULL
-    attributes(.data)$pems.tags <- NULL
-    class(.data) <- if(length(class(.data))==1) 
-          "data.frame" else
-               class(.data)[class(.data) != "pems"] 
+##    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("units", "pems.tags")]
+##    attributes(.data)$units <- NULL
+##    attributes(.data)$pems.tags <- NULL
+##    class(.data) <- if(length(class(.data))==1) 
+##          "data.frame" else
+##               class(.data)[class(.data) != "pems"] 
 
-    vars <- dplyr::select_vars(names(.data), !!! quos(...))
-    .data <- dplyr::select(.data, vars)
-    bare.bones$units <- dplyr::select(bare.bones$units, vars)
+##    vars <- dplyr::select_vars(names(.data), !!! quos(...))
+##    .data <- dplyr::select(.data, vars)
+##    bare.bones$units <- dplyr::select(bare.bones$units, vars)
 
     #rename
-    names(.data) <- names(vars)
-    for(i in names(vars))
-          attributes(.data[,i])$name <- i 
-    names(bare.bones$units) <- names(vars)
+##    names(.data) <- names(vars)
+##    for(i in names(vars))
+##          attributes(.data[,i])$name <- i 
+##    names(bare.bones$units) <- names(vars)
 
-    attributes(.data)$units <- bare.bones$units
-    attributes(.data)$pems.tags <- bare.bones$pems.tags
+##    attributes(.data)$units <- bare.bones$units
+##    attributes(.data)$pems.tags <- bare.bones$pems.tags
 
-    class(.data) <- if(length(class(.data))==1) 
-          "pems" else
-              unique(c("pems", class(.data)))
-    if("grouped_df" %in% class(.data))
-          class(.data) <- unique("grouped_df", class(.data))
+##    class(.data) <- if(length(class(.data))==1) 
+##          "pems" else
+##              unique(c("pems", class(.data)))
+##    if("grouped_df" %in% class(.data))
+##          class(.data) <- unique("grouped_df", class(.data))
 
 #  return as is (new pems)
-   .data
+##   .data
 
-}
+##}
 
 
-select_.pems <- function (.data, ..., warn=TRUE){
+##select_.pems <- function (.data, ..., warn=TRUE){
 
-   if(warn)
-        warning(paste("In select_.pems: dplyr underscores deprecated;", 
-        "see rlang `quo()` documentation", sep=" "), call. = FALSE)
+##   if(warn)
+##        warning(paste("In select_.pems: dplyr underscores deprecated;", 
+##        "see rlang `quo()` documentation", sep=" "), call. = FALSE)
    #########################
    #this is from select.pems
    #wrapping *_.data.frame needs 
    #  too much that is not exported
    #########################
 
-   .data <- rebuildPEMS(.data, "new")
+##   .data <- rebuildPEMS(.data, "new")
 
 #this is select.pems above
 
-    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("units", "pems.tags")]
-    attributes(.data)$units <- NULL
-    attributes(.data)$pems.tags <- NULL
-    class(.data) <- if(length(class(.data))==1) 
-          "data.frame" else
-               class(.data)[class(.data) != "pems"] 
-    vars <- dplyr::select_vars(names(.data), !!! quos(...))
-    .data <- dplyr::select(.data, vars)
-    bare.bones$units <- dplyr::select(bare.bones$units, vars)
-    names(.data) <- names(vars)
-    for(i in names(vars))
-          attributes(.data[,i])$name <- i 
-    names(bare.bones$units) <- names(vars)
-    attributes(.data)$units <- bare.bones$units
-    attributes(.data)$pems.tags <- bare.bones$pems.tags
-    class(.data) <- if(length(class(.data))==1) 
-          "pems" else
-              unique(c("pems", class(.data)))
-    if("grouped_df" %in% class(.data))
-          class(.data) <- unique("grouped_df", class(.data))
-   .data
+##    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("units", "pems.tags")]
+##    attributes(.data)$units <- NULL
+##    attributes(.data)$pems.tags <- NULL
+##    class(.data) <- if(length(class(.data))==1) 
+##          "data.frame" else
+##               class(.data)[class(.data) != "pems"] 
+##    vars <- dplyr::select_vars(names(.data), !!! quos(...))
+##    .data <- dplyr::select(.data, vars)
+##    bare.bones$units <- dplyr::select(bare.bones$units, vars)
+##    names(.data) <- names(vars)
+##    for(i in names(vars))
+##          attributes(.data[,i])$name <- i 
+##    names(bare.bones$units) <- names(vars)
+##    attributes(.data)$units <- bare.bones$units
+##    attributes(.data)$pems.tags <- bare.bones$pems.tags
+##    class(.data) <- if(length(class(.data))==1) 
+##          "pems" else
+##              unique(c("pems", class(.data)))
+##    if("grouped_df" %in% class(.data))
+##          class(.data) <- unique("grouped_df", class(.data))
+##   .data
 
-}
+##}
 
 
 #testing this
@@ -331,98 +331,6 @@ select_.pems <- function (.data, ..., warn=TRUE){
 
 
 
-#########################
-#########################
-##rename
-#########################
-#########################
-
-#kr v.0.1 31/11/2017
-
-#rename and rename_
-#pems.utils
-
-
-rename.pems <- function (.data, ...){
-
-#rename should change names but not dimensions
-#select(pems, speed=velocity)
-
-   .data <- rebuildPEMS(.data, "new")
-
-    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("units", "pems.tags")]
-    attributes(.data)$units <- NULL
-    attributes(.data)$pems.tags <- NULL
-    class(.data) <- if(length(class(.data))==1) 
-          "data.frame" else
-               class(.data)[class(.data) != "pems"] 
-################################
-    vars <- dplyr::rename_vars(names(.data), !!! quos(...))
-#this is select.pems above
-#with select_vars replaced with rename_vars in above
-################################   
-    .data <- dplyr::select(.data, vars)
-    bare.bones$units <- dplyr::select(bare.bones$units, vars)
-    names(.data) <- names(vars)
-    for(i in names(vars))
-          attributes(.data[,i])$name <- i 
-    names(bare.bones$units) <- names(vars)
-    attributes(.data)$units <- bare.bones$units
-    attributes(.data)$pems.tags <- bare.bones$pems.tags
-    class(.data) <- if(length(class(.data))==1) 
-          "pems" else
-              unique(c("pems", class(.data)))
-    if("grouped_df" %in% class(.data))
-          class(.data) <- unique("grouped_df", class(.data))
-   .data
-
-}
-
-#as rename.pems with warning
-
-
-rename_.pems <- function (.data, ..., warn = TRUE){
-
-   if(warn)
-        warning(paste("In rename_.pems: dplyr underscores deprecated;", 
-        "see rlang `quo()` documentation", sep=" "), call. = FALSE)
-
-   .data <- rebuildPEMS(.data, "new")
-
-    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("units", "pems.tags")]
-    attributes(.data)$units <- NULL
-    attributes(.data)$pems.tags <- NULL
-    class(.data) <- if(length(class(.data))==1) 
-          "data.frame" else
-               class(.data)[class(.data) != "pems"] 
-    vars <- dplyr::rename_vars(names(.data), !!! quos(...))
-    .data <- dplyr::select(.data, vars)
-    bare.bones$units <- dplyr::select(bare.bones$units, vars)
-    names(.data) <- names(vars)
-    for(i in names(vars))
-          attributes(.data[,i])$name <- i 
-    names(bare.bones$units) <- names(vars)
-    attributes(.data)$units <- bare.bones$units
-    attributes(.data)$pems.tags <- bare.bones$pems.tags
-    class(.data) <- if(length(class(.data))==1) 
-          "pems" else
-              unique(c("pems", class(.data)))
-    if("grouped_df" %in% class(.data))
-          class(.data) <- unique("grouped_df", class(.data))
-   .data
-
-}
-
-
-#write code in form... 
-#function(d, a) {
-#a <- enquo(a)
-#select(d, !!a)
-#}
-
-#is there a enquos to enquo like quos to quos...
-#plans to export function for *_.* methods???
-
 
 
 
@@ -813,112 +721,6 @@ mutate_.pems <- function(.data, ..., units=NULL, warn=TRUE) {
 
 
 
-#########################
-#########################
-##summarise
-#########################
-#########################
-
-#kr v.0.1 05/11/2017
-
-#summarise, etc....
-#pems.utils
-
-
-
-
-summarise.pems <- function(.data, ...) {
-
-#summarise changes everything
-#suggest this drops whatever
-
-##summarise.data.frame <- function(.data, ...) {
-##  as.data.frame(summarise(tibble::as_tibble(.data), ...)) 
-##}
-
-#new structure
-
-    .data <- rebuildPEMS(.data, "new")
-
-    ####################
-    #break
-    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("class", "units", "pems.tags")]
-    attributes(.data)$units <- NULL
-    attributes(.data)$pems.tags <- NULL
-    class(.data) <- if(length(class(.data))==1) 
-          "data.frame" else
-               class(.data)[class(.data) != "pems"] 
-    ######################
-
-#    .data <- as.data.frame(summarise(tibble::as_tibble(.data), ...))
-    .data <- dplyr::summarise(.data, ...) 
-   
-    #######################
-    #rebuild
-    ##attributes(.data)$units <- bare.bones$units
-    ##attributes(.data)$pems.tags <- bare.bones$pems.tags
-    ##class(.data) <- if(length(class(.data))==1) 
-    ##      "pems" else
-    ##          unique(c("pems", class(.data)))
-    #######################
-    ##rebuildPEMS(.data, "old")
-
-    .data
-
-}
-
-#like above but warning
-
-summarise_.pems <- function(.data, ..., warn=TRUE) {
-
-#summarise changes everything
-#suggest this drops whatever
-
-##summarise.data.frame <- function(.data, ...) {
-##  as.data.frame(summarise(tibble::as_tibble(.data), ...)) 
-##}
-
-    if(warn)
-        warning(paste("In summarise_.pems: dplyr underscores deprecated;", 
-        "see rlang `quo()` documentation", sep=" "), call. = FALSE)
-
-
-#new structure
-
-    .data <- rebuildPEMS(.data, "new")
-
-    ####################
-    #break
-    bare.bones <- attributes(.data)[names(attributes(.data)) %in% c("class", "units", "pems.tags")]
-    attributes(.data)$units <- NULL
-    attributes(.data)$pems.tags <- NULL
-    class(.data) <- if(length(class(.data))==1) 
-          "data.frame" else
-               class(.data)[class(.data) != "pems"] 
-    ######################
-
-#    .data <- as.data.frame(summarise(tibble::as_tibble(.data), ...))
-    .data <- dplyr::summarise(.data, ...)     
-
-    #######################
-    #rebuild
-    ##attributes(.data)$units <- bare.bones$units
-    ##attributes(.data)$pems.tags <- bare.bones$pems.tags
-    ##class(.data) <- if(length(class(.data))==1) 
-    ##      "pems" else
-    ##          unique(c("pems", class(.data)))
-    #######################
-    ##rebuildPEMS(.data, "old")
-
-    ##output 
-    #whatever summarise gives us...
-    .data
-
-}
-
-
-
-
 
 
 
